//---------------------------------------------------------------------------------
/// \file	SimpleCommand.cpp
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	This is the simplest possible example of how to write a mel command
///			that can be added into Maya via a plugin. You can call the command 
///			from mel by typing, "SimpleCommand". This simply executes a mel call 
///			via MGlobal::executeCommand to create a sphere.
///	
//---------------------------------------------------------------------------------

#ifdef WIN32
	#define NT_PLUGIN
#endif

// required to link the libraries
#ifdef WIN32

	#pragma comment(lib,"Image.lib")
	#pragma comment(lib,"Foundation.lib")
	#pragma comment(lib,"OpenMaya.lib")
	#pragma comment(lib,"OpenMayaFx.lib")
	#pragma comment(lib,"OpenMayaUi.lib")
	#pragma comment(lib,"OpenMayaAnim.lib")

#endif

// include any maya headers we need.
#include <maya/MSimple.h>
#include <maya/MGlobal.h>
#include <maya/MFnMesh.h>
#include <maya/MFnTransform.h>
#include <maya/MFnPointLight.h>
#include <maya/MItDependencyNodes.h>
#include <maya/MPointArray.h>
#include <maya/MItDependencyNodes.h>

//---------------------------------------------------------------------------------
// Use a helper macro to register a command with Maya.  This creates and
// registers a command that does not support undo or redo.  The
// created class derives off of MPxCommand.
//
DeclareSimpleCommand( SimpleCommand, "A simple mel function example", "1.0");

//---------------------------------------------------------------------------------
/// \brief	This function impliments our very first simple command plugin.
/// \param	args - the argument list that was passes to the command from MEL
/// \return	MS::kSuccess - command succeeded
///			MS::kFailure - command failed (returning this value will cause the
///         	           MEL script that is being run to terminate unless the
///         	           error is caught using a "catch" statement.
///
MStatus SimpleCommand::doIt( const MArgList& args )

{
	// the return status
	MStatus stat = MS::kSuccess;

	// we need to use a light function set to do anything useful ;)
	MFnPointLight fnLight;

	// create a point light that has no transform
	MObject oParent = fnLight.create();

	// attach a function set to the transform
	MFnTransform fnX( oParent );

	// re-bind the function set to the light
	fnLight.setObject( fnX.parent(0) );

	MColor col;
	col.r = 1;
	col.g = 0;
	col.b = 0;

	// set the colour of the light
	fnLight.setColor( col );

	// iterate over all of the nodes in the scene.
	MItDependencyNodes it;
	while( !it.isDone() )
	{

		it.next();
	}

	return stat;
}
